% NLPaperPlots
% This file generates the plots that appear in the paper for the
% example of an nonlinear delayed system.

%%
% Nyquist Plot: QC circles at DMFrequency
figure(1);
clf;
th = linspace(0,2*pi,100);
PI(:,:,1) = delayiqc(IQCtype(1),LinDelayMarginLB,IQCwt(1));
PI(:,:,2) = delayiqc(IQCtype(2),LinDelayMarginLB,IQCwt(2));
for i=1:3
    if i==3
        PIomeg = freqresp(infoLIN.PIopt,DMFrequency);
        linetype = 'g';
    else
        PIomeg = freqresp(PI(:,:,i),DMFrequency);
        linetype = 'g-.';
    end
    [~,c,r]=iqcint(PIomeg);
    plot(real(c)+r*sin(th),imag(c)+r*cos(th),linetype,'color',mycolor('coolblue'));
    hold on;
end
xlabel('Real');
ylabel('Imag');
axis([-2.5 1 -1.5 1.5]);
grid on;

% Mark Stau at critical frequency
Staubar = exp(-j*DMFrequency*LinDelayMarginLB)-1;
plot(real(Staubar),imag(Staubar),'o','LineWidth',4,'MarkerSize',10,'color',mycolor('maroon'))

% Add Text Labels
ah = [];
ah(1)=annotation('textarrow',[0.24 0.3],[0.8 0.72],'String','QC(\Pi_1)');
ah(2)=annotation('textarrow',[0.46 0.51],[0.68 0.60],'String','QC(\Pi_{opt})');
ah(3)=annotation('textarrow',[0.8 0.7],[0.3 0.34],'String','QC(\Pi_3)');
ah(4)=annotation('textarrow',[0.72 0.63],[0.2 0.32],'String','S_{\tau}');
ah(5)=text(0.79,-0.68,'-');
ah(6)=text(0.19,-1.19,'^');
set(ah,'FontSize',12)
hold off

if exist('garyfyFigure','file')
    garyfyFigure;
end
% matlab2tikz('ex1circles.tex')


%%
% Nyquist plot of destabilizing perturbations
figure(2);
clf
T = feedback(L,1);
[rr,ii]=nyquist(-1/T);
plot(rr(:),ii(:),'b');
hold on;

% Circles for multipliers types 2 and 3
PIomeg = freqresp( delayiqc(2,LinDelayMarginLB) ,DMFrequency);
[~,c,r]=iqcint(PIomeg);
plot(real(c)+r*sin(th),imag(c)+r*cos(th),'g-.');
hold on;
PIomeg = freqresp( delayiqc(3,LinDelayMarginLB) ,DMFrequency);
[~,c,r]=iqcint(PIomeg);
plot(real(c)+r*sin(th),imag(c)+r*cos(th),'g-.');

plot(real(Staubar),imag(Staubar),'bo','LineWidth',4,'MarkerSize',10)
ah = [];
ah(1)=annotation('textarrow',[0.68 0.76],[0.85 0.85],'String','\Delta_{bad}(j\omega)');
ah(2)=annotation('textarrow',[0.8 0.725],[0.3 0.36],'String','QC(\Pi_3)');
ah(3)=annotation('textarrow',[0.72 0.63],[0.2 0.32],'String','S_{\tau}');
ah(4)=text(0.79,-0.8,'--');
ah(5)=text(0.2,-1.19,'^');
ah(6)=annotation('textarrow',[0.46 0.55],[0.70 0.64],'String','QC(\Pi_2)');
ah(7)=text(-1.2,0.79,'--');
set(ah,'FontSize',12)
hold off;
xlabel('Real');
ylabel('Imag');
axis([-2.5 1 -1.5 1.5]);
grid on;
if exist('garyfyFigure','file')
    garyfyFigure;
end

%%
% Plot gain versus time delay
figure(3);
plot(taug,g,'color',mycolor('darkgray'))
hold on
plot(taug,gUB,'--','color',mycolor('coolblue'))
xlabel('Time Delay, tau (sec)');
ylabel('L2 gain from ref to error');
legend('Freq. Resp.','IQC UB');

hold on;
plot(taugNL,gNLUB,'-.','color',mycolor('maroon'));
hold off;
legend off;
grid off;
ylim([0, 10*g(1)]);
xlim([0, DelayMargin]);

ah = [];
ah(1)=annotation('textarrow',[0.32 0.40],[0.8 0.8],'String','NonLin-IQC');
ah(2)=annotation('textarrow',[0.62 0.76],[0.69 0.68],'String','Lin-IQC');
ah(3)=annotation('textarrow',[0.7 0.63],[0.2 0.32],'String','Lin-Freq. Resp.');
set(ah,'FontSize',12)

if exist('garyfyFigure','file')
    garyfyFigure;
end

% matlab2tikz('ex1results.tex')
